@@ -1,4 +1,4 @@
-# Copyright 2008-2020  Sutou Kouhei <kou@cozmixng.org>
+# Copyright 2008-2021  Sutou Kouhei <kou@cozmixng.org>
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -463,6 +463,7 @@ class PackageConfig
       paths << (pkg_config_prefix + "libx32/pkgconfig").to_s
       paths << (pkg_config_prefix + "lib/pkgconfig").to_s
       paths << (pkg_config_prefix + "libdata/pkgconfig").to_s
+      paths << (pkg_config_prefix + "share/pkgconfig").to_s
     end
     if /-darwin\d[\d\.]*\z/ =~ RUBY_PLATFORM and
         /\A(\d+\.\d+)/ =~ `sw_vers -productVersion`
@@ -485,7 +486,11 @@ class PackageConfig
         homebrew_repository_candidates << Pathname(homebrew_repository)
       end
       homebrew_repository_candidates.uniq.each do |candidate|
-        path = candidate + "Library/Homebrew/os/mac/pkgconfig/#{mac_os_version}"
+        pkgconfig_base_path = candidate + "Library/Homebrew/os/mac/pkgconfig"
+        path = pkgconfig_base_path + mac_os_version
+        unless path.exist?
+          path = pkgconfig_base_path + mac_os_version.gsub(/\.\d+\z/, "")
+        end
         paths << path.to_s if path.exist?
       end
     end
